==> spanishdelight-1.20.1-1.0.7-sources.jar: io/github/macuguita/item/ModItemGroups.java <==
package io.github.macuguita.item;

import io.github.macuguita.SpanishDelightRefabricated;
import io.github.macuguita.block.ModBlocks;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.minecraft.class_1761;
import net.minecraft.class_1799;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public class ModItemGroups {

    public static class_1761 SDELIGHT_TAB = class_2378.method_10230(class_7923.field_44687,
            new class_2960(SpanishDelightRefabricated.MOD_ID, "sdelight_tab"),
            FabricItemGroup.builder().method_47321(class_2561.method_43471("creativetab.sdelight_tab"))
                    .method_47320(() -> new class_1799(ModItems.SPANISH_TORTILLA)).method_47317((displayContext, entries) -> {
                        entries.method_45421(ModItems.PAPRIKA);
                        entries.method_45421(ModItems.SLICED_POTATO);
                        entries.method_45421(ModItems.SLICED_ONION);
                        entries.method_45421(ModItems.GARLIC);
                        entries.method_45421(ModItems.GREEN_BEAN);
                        entries.method_45421(ModItems.RED_PEPPER);
                        entries.method_45421(ModItems.GREEN_PEPPER);
                        entries.method_45421(ModItems.SQUID_RING);
                        entries.method_45421(ModItems.SPANISH_TORTILLA);
                        entries.method_45421(ModItems.PAELLA);
                        entries.method_45421(ModItems.PIL_PIL_COD);
                        entries.method_45421(ModItems.CROQUETTES);
                        entries.method_45421(ModItems.BRAVA_POTATOES);
                        entries.method_45421(ModItems.CHURRO);
                        entries.method_45421(ModItems.GAZPACHO);
                        entries.method_45421(ModItems.PANTUMACA);
                        entries.method_45421(ModItems.FRIED_SQUID_RING);
                        entries.method_45421(ModBlocks.WILD_GARLIC.method_8389());
                        entries.method_45421(ModBlocks.WILD_RED_PEPPER.method_8389());
                        entries.method_45421(ModBlocks.WILD_GREEN_PEPPER.method_8389());
                    }).method_47324());

    public static void registerItemGroups() {
        SpanishDelightRefabricated.LOGGER.info("Registering Item Groups for" + SpanishDelightRefabricated.MOD_ID);
    }
}

==> spanishdelight-1.21.10-1.0.7-sources.jar: io/github/macuguita/item/ModItemGroups.java <==
package io.github.macuguita.item;

import io.github.macuguita.SpanishDelightRefabricated;
import io.github.macuguita.block.ModBlocks;
import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroup;
import net.minecraft.class_1761;
import net.minecraft.class_1799;
import net.minecraft.class_2378;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public class ModItemGroups {

    public static class_1761 SDELIGHT_TAB = class_2378.method_10230(class_7923.field_44687,
            class_2960.method_60655(SpanishDelightRefabricated.MOD_ID, "sdelight_tab"),
            FabricItemGroup.builder().method_47321(class_2561.method_43471("creativetab.sdelight_tab"))
                    .method_47320(() -> new class_1799(ModItems.SPANISH_TORTILLA)).method_47317((displayContext, entries) -> {
                        entries.method_45421(ModItems.PAPRIKA);
                        entries.method_45421(ModItems.SLICED_POTATO);
                        entries.method_45421(ModItems.SLICED_ONION);
                        entries.method_45421(ModItems.GARLIC);
                        entries.method_45421(ModItems.GREEN_BEAN);
                        entries.method_45421(ModItems.RED_PEPPER);
                        entries.method_45421(ModItems.GREEN_PEPPER);
                        entries.method_45421(ModItems.SQUID_RING);
                        entries.method_45421(ModItems.SPANISH_TORTILLA);
                        entries.method_45421(ModItems.PAELLA);
                        entries.method_45421(ModItems.PIL_PIL_COD);
                        entries.method_45421(ModItems.CROQUETTES);
                        entries.method_45421(ModItems.BRAVA_POTATOES);
                        entries.method_45421(ModItems.CHURRO);
                        entries.method_45421(ModItems.GAZPACHO);
                        entries.method_45421(ModItems.PANTUMACA);
                        entries.method_45421(ModItems.FRIED_SQUID_RING);
                        entries.method_45421(ModBlocks.WILD_GARLIC.method_8389());
                        entries.method_45421(ModBlocks.WILD_RED_PEPPER.method_8389());
                        entries.method_45421(ModBlocks.WILD_GREEN_PEPPER.method_8389());
                    }).method_47324());

    public static void registerItemGroups() {
        SpanishDelightRefabricated.LOGGER.info("Registering Item Groups for" + SpanishDelightRefabricated.MOD_ID);
    }
}
